@@ -4,7 +4,7 @@
 pub struct Document {
     /// Required. If the type is not set or is `TYPE_UNSPECIFIED`,
     /// returns an `INVALID_ARGUMENT` error.
-    #[prost(enumeration = "document::Type", tag = "1")]
+    #[prost(enumeration="document::Type", tag="1")]
     pub r#type: i32,
     /// The language of the document (if not specified, the language is
     /// automatically detected). Both ISO and BCP-47 language codes are
@@ -14,11 +14,11 @@ pub struct Document {
     /// currently supported languages for each API method. If the language (either
     /// specified by the caller or automatically detected) is not supported by the
     /// called API method, an `INVALID_ARGUMENT` error is returned.
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub language: ::prost::alloc::string::String,
     /// The source of the document: a string containing the content or a
     /// Google Cloud Storage URI.
-    #[prost(oneof = "document::Source", tags = "2, 3")]
+    #[prost(oneof="document::Source", tags="2, 3")]
     pub source: ::core::option::Option<document::Source>,
 }
 /// Nested message and enum types in `Document`.
@@ -40,13 +40,13 @@ pub mod document {
     pub enum Source {
         /// The content of the input in string format.
         /// Cloud audit logging exempt since it is based on user data.
-        #[prost(string, tag = "2")]
+        #[prost(string, tag="2")]
         Content(::prost::alloc::string::String),
         /// The Google Cloud Storage URI where the file content is located.
         /// This URI must be of the form: gs://bucket_name/object_name. For more
         /// details, see <https://cloud.google.com/storage/docs/reference-uris.>
         /// NOTE: Cloud Storage object versioning is not supported.
-        #[prost(string, tag = "3")]
+        #[prost(string, tag="3")]
         GcsContentUri(::prost::alloc::string::String),
     }
 }
@@ -54,12 +54,12 @@ pub mod document {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Sentence {
     /// The sentence text.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub text: ::core::option::Option<TextSpan>,
     /// For calls to \[AnalyzeSentiment][\] or if
     /// \[AnnotateTextRequest.Features.extract_document_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_document_sentiment\] is set to
     /// true, this field will contain the sentiment for the sentence.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub sentiment: ::core::option::Option<Sentiment>,
 }
 /// Represents a phrase in the text that is a known entity, such as
@@ -68,38 +68,35 @@ pub struct Sentence {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Entity {
     /// The representative name for the entity.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// The entity type.
-    #[prost(enumeration = "entity::Type", tag = "2")]
+    #[prost(enumeration="entity::Type", tag="2")]
     pub r#type: i32,
     /// Metadata associated with the entity.
     ///
     /// For most entity types, the metadata is a Wikipedia URL (`wikipedia_url`)
     /// and Knowledge Graph MID (`mid`), if they are available. For the metadata
     /// associated with other entity types, see the Type table below.
-    #[prost(btree_map = "string, string", tag = "3")]
-    pub metadata: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        ::prost::alloc::string::String,
-    >,
+    #[prost(btree_map="string, string", tag="3")]
+    pub metadata: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
     /// The salience score associated with the entity in the [0, 1.0] range.
     ///
     /// The salience score for an entity provides information about the
     /// importance or centrality of that entity to the entire document text.
     /// Scores closer to 0 are less salient, while scores closer to 1.0 are highly
     /// salient.
-    #[prost(float, tag = "4")]
+    #[prost(float, tag="4")]
     pub salience: f32,
     /// The mentions of this entity in the input document. The API currently
     /// supports proper noun mentions.
-    #[prost(message, repeated, tag = "5")]
+    #[prost(message, repeated, tag="5")]
     pub mentions: ::prost::alloc::vec::Vec<EntityMention>,
     /// For calls to \[AnalyzeEntitySentiment][\] or if
     /// \[AnnotateTextRequest.Features.extract_entity_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_entity_sentiment\] is set to
     /// true, this field will contain the aggregate sentiment expressed for this
     /// entity in the provided document.
-    #[prost(message, optional, tag = "6")]
+    #[prost(message, optional, tag="6")]
     pub sentiment: ::core::option::Option<Sentiment>,
 }
 /// Nested message and enum types in `Entity`.
@@ -168,16 +165,16 @@ pub mod entity {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Token {
     /// The token text.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub text: ::core::option::Option<TextSpan>,
     /// Parts of speech tag for this token.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub part_of_speech: ::core::option::Option<PartOfSpeech>,
     /// Dependency tree parse for this token.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub dependency_edge: ::core::option::Option<DependencyEdge>,
     /// \[Lemma\](<https://en.wikipedia.org/wiki/Lemma_%28morphology%29>) of the token.
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub lemma: ::prost::alloc::string::String,
 }
 /// Represents the feeling associated with the entire text or entities in
@@ -187,11 +184,11 @@ pub struct Sentiment {
     /// A non-negative number in the [0, +inf) range, which represents
     /// the absolute magnitude of sentiment regardless of score (positive or
     /// negative).
-    #[prost(float, tag = "2")]
+    #[prost(float, tag="2")]
     pub magnitude: f32,
     /// Sentiment score between -1.0 (negative sentiment) and 1.0
     /// (positive sentiment).
-    #[prost(float, tag = "3")]
+    #[prost(float, tag="3")]
     pub score: f32,
 }
 /// Represents part of speech information for a token. Parts of speech
@@ -200,40 +197,40 @@ pub struct Sentiment {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct PartOfSpeech {
     /// The part of speech tag.
-    #[prost(enumeration = "part_of_speech::Tag", tag = "1")]
+    #[prost(enumeration="part_of_speech::Tag", tag="1")]
     pub tag: i32,
     /// The grammatical aspect.
-    #[prost(enumeration = "part_of_speech::Aspect", tag = "2")]
+    #[prost(enumeration="part_of_speech::Aspect", tag="2")]
     pub aspect: i32,
     /// The grammatical case.
-    #[prost(enumeration = "part_of_speech::Case", tag = "3")]
+    #[prost(enumeration="part_of_speech::Case", tag="3")]
     pub case: i32,
     /// The grammatical form.
-    #[prost(enumeration = "part_of_speech::Form", tag = "4")]
+    #[prost(enumeration="part_of_speech::Form", tag="4")]
     pub form: i32,
     /// The grammatical gender.
-    #[prost(enumeration = "part_of_speech::Gender", tag = "5")]
+    #[prost(enumeration="part_of_speech::Gender", tag="5")]
     pub gender: i32,
     /// The grammatical mood.
-    #[prost(enumeration = "part_of_speech::Mood", tag = "6")]
+    #[prost(enumeration="part_of_speech::Mood", tag="6")]
     pub mood: i32,
     /// The grammatical number.
-    #[prost(enumeration = "part_of_speech::Number", tag = "7")]
+    #[prost(enumeration="part_of_speech::Number", tag="7")]
     pub number: i32,
     /// The grammatical person.
-    #[prost(enumeration = "part_of_speech::Person", tag = "8")]
+    #[prost(enumeration="part_of_speech::Person", tag="8")]
     pub person: i32,
     /// The grammatical properness.
-    #[prost(enumeration = "part_of_speech::Proper", tag = "9")]
+    #[prost(enumeration="part_of_speech::Proper", tag="9")]
     pub proper: i32,
     /// The grammatical reciprocity.
-    #[prost(enumeration = "part_of_speech::Reciprocity", tag = "10")]
+    #[prost(enumeration="part_of_speech::Reciprocity", tag="10")]
     pub reciprocity: i32,
     /// The grammatical tense.
-    #[prost(enumeration = "part_of_speech::Tense", tag = "11")]
+    #[prost(enumeration="part_of_speech::Tense", tag="11")]
     pub tense: i32,
     /// The grammatical voice.
-    #[prost(enumeration = "part_of_speech::Voice", tag = "12")]
+    #[prost(enumeration="part_of_speech::Voice", tag="12")]
     pub voice: i32,
 }
 /// Nested message and enum types in `PartOfSpeech`.
@@ -480,10 +477,10 @@ pub struct DependencyEdge {
     /// The index is the position of the token in the array of tokens returned
     /// by the API method. If this token is a root token, then the
     /// `head_token_index` is its own index.
-    #[prost(int32, tag = "1")]
+    #[prost(int32, tag="1")]
     pub head_token_index: i32,
     /// The parse label for the token.
-    #[prost(enumeration = "dependency_edge::Label", tag = "2")]
+    #[prost(enumeration="dependency_edge::Label", tag="2")]
     pub label: i32,
 }
 /// Nested message and enum types in `DependencyEdge`.
@@ -665,16 +662,16 @@ pub mod dependency_edge {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct EntityMention {
     /// The mention text.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub text: ::core::option::Option<TextSpan>,
     /// The type of the entity mention.
-    #[prost(enumeration = "entity_mention::Type", tag = "2")]
+    #[prost(enumeration="entity_mention::Type", tag="2")]
     pub r#type: i32,
     /// For calls to \[AnalyzeEntitySentiment][\] or if
     /// \[AnnotateTextRequest.Features.extract_entity_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_entity_sentiment\] is set to
     /// true, this field will contain the sentiment expressed for this mention of
     /// the entity in the provided document.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub sentiment: ::core::option::Option<Sentiment>,
 }
 /// Nested message and enum types in `EntityMention`.
@@ -695,11 +692,11 @@ pub mod entity_mention {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct TextSpan {
     /// The content of the output text.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub content: ::prost::alloc::string::String,
     /// The API calculates the beginning offset of the content in the original
     /// document according to the \[EncodingType][google.cloud.language.v1.EncodingType\] specified in the API request.
-    #[prost(int32, tag = "2")]
+    #[prost(int32, tag="2")]
     pub begin_offset: i32,
 }
 /// Represents a category returned from the text classifier.
@@ -707,119 +704,119 @@ pub struct TextSpan {
 pub struct ClassificationCategory {
     /// The name of the category representing the document, from the [predefined
     /// taxonomy](<https://cloud.google.com/natural-language/docs/categories>).
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// The classifier's confidence of the category. Number represents how certain
     /// the classifier is that this category represents the given text.
-    #[prost(float, tag = "2")]
+    #[prost(float, tag="2")]
     pub confidence: f32,
 }
 /// The sentiment analysis request message.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnalyzeSentimentRequest {
     /// Input document.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub document: ::core::option::Option<Document>,
     /// The encoding type used by the API to calculate sentence offsets.
-    #[prost(enumeration = "EncodingType", tag = "2")]
+    #[prost(enumeration="EncodingType", tag="2")]
     pub encoding_type: i32,
 }
 /// The sentiment analysis response message.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnalyzeSentimentResponse {
     /// The overall sentiment of the input document.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub document_sentiment: ::core::option::Option<Sentiment>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
     /// See \[Document.language][google.cloud.language.v1.Document.language\] field for more details.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub language: ::prost::alloc::string::String,
     /// The sentiment for all the sentences in the document.
-    #[prost(message, repeated, tag = "3")]
+    #[prost(message, repeated, tag="3")]
     pub sentences: ::prost::alloc::vec::Vec<Sentence>,
 }
 /// The entity-level sentiment analysis request message.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnalyzeEntitySentimentRequest {
     /// Input document.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub document: ::core::option::Option<Document>,
     /// The encoding type used by the API to calculate offsets.
-    #[prost(enumeration = "EncodingType", tag = "2")]
+    #[prost(enumeration="EncodingType", tag="2")]
     pub encoding_type: i32,
 }
 /// The entity-level sentiment analysis response message.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnalyzeEntitySentimentResponse {
     /// The recognized entities in the input document with associated sentiments.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub entities: ::prost::alloc::vec::Vec<Entity>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
     /// See \[Document.language][google.cloud.language.v1.Document.language\] field for more details.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub language: ::prost::alloc::string::String,
 }
 /// The entity analysis request message.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnalyzeEntitiesRequest {
     /// Input document.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub document: ::core::option::Option<Document>,
     /// The encoding type used by the API to calculate offsets.
-    #[prost(enumeration = "EncodingType", tag = "2")]
+    #[prost(enumeration="EncodingType", tag="2")]
     pub encoding_type: i32,
 }
 /// The entity analysis response message.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnalyzeEntitiesResponse {
     /// The recognized entities in the input document.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub entities: ::prost::alloc::vec::Vec<Entity>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
     /// See \[Document.language][google.cloud.language.v1.Document.language\] field for more details.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub language: ::prost::alloc::string::String,
 }
 /// The syntax analysis request message.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnalyzeSyntaxRequest {
     /// Input document.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub document: ::core::option::Option<Document>,
     /// The encoding type used by the API to calculate offsets.
-    #[prost(enumeration = "EncodingType", tag = "2")]
+    #[prost(enumeration="EncodingType", tag="2")]
     pub encoding_type: i32,
 }
 /// The syntax analysis response message.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnalyzeSyntaxResponse {
     /// Sentences in the input document.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub sentences: ::prost::alloc::vec::Vec<Sentence>,
     /// Tokens, along with their syntactic information, in the input document.
-    #[prost(message, repeated, tag = "2")]
+    #[prost(message, repeated, tag="2")]
     pub tokens: ::prost::alloc::vec::Vec<Token>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
     /// See \[Document.language][google.cloud.language.v1.Document.language\] field for more details.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub language: ::prost::alloc::string::String,
 }
 /// The document classification request message.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ClassifyTextRequest {
     /// Input document.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub document: ::core::option::Option<Document>,
 }
 /// The document classification response message.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ClassifyTextResponse {
     /// Categories representing the input document.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub categories: ::prost::alloc::vec::Vec<ClassificationCategory>,
 }
 /// The request message for the text annotation API, which can perform multiple
@@ -827,13 +824,13 @@ pub struct ClassifyTextResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnnotateTextRequest {
     /// Input document.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub document: ::core::option::Option<Document>,
     /// The enabled features.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub features: ::core::option::Option<annotate_text_request::Features>,
     /// The encoding type used by the API to calculate offsets.
-    #[prost(enumeration = "EncodingType", tag = "3")]
+    #[prost(enumeration="EncodingType", tag="3")]
     pub encoding_type: i32,
 }
 /// Nested message and enum types in `AnnotateTextRequest`.
@@ -843,19 +840,19 @@ pub mod annotate_text_request {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Features {
         /// Extract syntax information.
-        #[prost(bool, tag = "1")]
+        #[prost(bool, tag="1")]
         pub extract_syntax: bool,
         /// Extract entities.
-        #[prost(bool, tag = "2")]
+        #[prost(bool, tag="2")]
         pub extract_entities: bool,
         /// Extract document-level sentiment.
-        #[prost(bool, tag = "3")]
+        #[prost(bool, tag="3")]
         pub extract_document_sentiment: bool,
         /// Extract entities and their associated sentiment.
-        #[prost(bool, tag = "4")]
+        #[prost(bool, tag="4")]
         pub extract_entity_sentiment: bool,
         /// Classify the full document into categories.
-        #[prost(bool, tag = "6")]
+        #[prost(bool, tag="6")]
         pub classify_text: bool,
     }
 }
@@ -864,29 +861,29 @@ pub mod annotate_text_request {
 pub struct AnnotateTextResponse {
     /// Sentences in the input document. Populated if the user enables
     /// \[AnnotateTextRequest.Features.extract_syntax][google.cloud.language.v1.AnnotateTextRequest.Features.extract_syntax\].
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub sentences: ::prost::alloc::vec::Vec<Sentence>,
     /// Tokens, along with their syntactic information, in the input document.
     /// Populated if the user enables
     /// \[AnnotateTextRequest.Features.extract_syntax][google.cloud.language.v1.AnnotateTextRequest.Features.extract_syntax\].
-    #[prost(message, repeated, tag = "2")]
+    #[prost(message, repeated, tag="2")]
     pub tokens: ::prost::alloc::vec::Vec<Token>,
     /// Entities, along with their semantic information, in the input document.
     /// Populated if the user enables
     /// \[AnnotateTextRequest.Features.extract_entities][google.cloud.language.v1.AnnotateTextRequest.Features.extract_entities\].
-    #[prost(message, repeated, tag = "3")]
+    #[prost(message, repeated, tag="3")]
     pub entities: ::prost::alloc::vec::Vec<Entity>,
     /// The overall sentiment for the document. Populated if the user enables
     /// \[AnnotateTextRequest.Features.extract_document_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_document_sentiment\].
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub document_sentiment: ::core::option::Option<Sentiment>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
     /// See \[Document.language][google.cloud.language.v1.Document.language\] field for more details.
-    #[prost(string, tag = "5")]
+    #[prost(string, tag="5")]
     pub language: ::prost::alloc::string::String,
     /// Categories identified in the input document.
-    #[prost(message, repeated, tag = "6")]
+    #[prost(message, repeated, tag="6")]
     pub categories: ::prost::alloc::vec::Vec<ClassificationCategory>,
 }
 /// Represents the text encoding that the caller uses to process the output.
@@ -913,12 +910,12 @@ pub enum EncodingType {
     /// that uses this encoding natively.
     Utf32 = 3,
 }
-#[doc = r" Generated client implementations."]
+/// Generated client implementations.
 pub mod language_service_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " Provides text analysis operations such as sentiment analysis and entity"]
-    #[doc = " recognition."]
+    /// Provides text analysis operations such as sentiment analysis and entity
+    /// recognition.
     #[derive(Debug, Clone)]
     pub struct LanguageServiceClient<T> {
         inner: tonic::client::Grpc<T>,
@@ -926,8 +923,8 @@ pub mod language_service_client {
     impl<T> LanguageServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -946,126 +943,150 @@ pub mod language_service_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             LanguageServiceClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Analyzes the sentiment of the provided text."]
+        /// Analyzes the sentiment of the provided text.
         pub async fn analyze_sentiment(
             &mut self,
             request: impl tonic::IntoRequest<super::AnalyzeSentimentRequest>,
         ) -> Result<tonic::Response<super::AnalyzeSentimentResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.language.v1.LanguageService/AnalyzeSentiment",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Finds named entities (currently proper names and common nouns) in the text"]
-        #[doc = " along with entity types, salience, mentions for each entity, and"]
-        #[doc = " other properties."]
+        /// Finds named entities (currently proper names and common nouns) in the text
+        /// along with entity types, salience, mentions for each entity, and
+        /// other properties.
         pub async fn analyze_entities(
             &mut self,
             request: impl tonic::IntoRequest<super::AnalyzeEntitiesRequest>,
         ) -> Result<tonic::Response<super::AnalyzeEntitiesResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.language.v1.LanguageService/AnalyzeEntities",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1.LanguageService.AnalyzeEntities] in the text and analyzes"]
-        #[doc = " sentiment associated with each entity and its mentions."]
+        /// Finds entities, similar to [AnalyzeEntities][google.cloud.language.v1.LanguageService.AnalyzeEntities] in the text and analyzes
+        /// sentiment associated with each entity and its mentions.
         pub async fn analyze_entity_sentiment(
             &mut self,
             request: impl tonic::IntoRequest<super::AnalyzeEntitySentimentRequest>,
-        ) -> Result<tonic::Response<super::AnalyzeEntitySentimentResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+        ) -> Result<
+                tonic::Response<super::AnalyzeEntitySentimentResponse>,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.language.v1.LanguageService/AnalyzeEntitySentiment",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Analyzes the syntax of the text and provides sentence boundaries and"]
-        #[doc = " tokenization along with part of speech tags, dependency trees, and other"]
-        #[doc = " properties."]
+        /// Analyzes the syntax of the text and provides sentence boundaries and
+        /// tokenization along with part of speech tags, dependency trees, and other
+        /// properties.
         pub async fn analyze_syntax(
             &mut self,
             request: impl tonic::IntoRequest<super::AnalyzeSyntaxRequest>,
         ) -> Result<tonic::Response<super::AnalyzeSyntaxResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.language.v1.LanguageService/AnalyzeSyntax",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Classifies a document into categories."]
+        /// Classifies a document into categories.
         pub async fn classify_text(
             &mut self,
             request: impl tonic::IntoRequest<super::ClassifyTextRequest>,
         ) -> Result<tonic::Response<super::ClassifyTextResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.language.v1.LanguageService/ClassifyText",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " A convenience method that provides all the features that analyzeSentiment,"]
-        #[doc = " analyzeEntities, and analyzeSyntax provide in one call."]
+        /// A convenience method that provides all the features that analyzeSentiment,
+        /// analyzeEntities, and analyzeSyntax provide in one call.
         pub async fn annotate_text(
             &mut self,
             request: impl tonic::IntoRequest<super::AnnotateTextRequest>,
         ) -> Result<tonic::Response<super::AnnotateTextResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.language.v1.LanguageService/AnnotateText",
